import pathlib

import setuptools

_REPO_URL = "https://git.hammerle.me/fphammerle/intertechno-cc1101"

setuptools.setup(
    name="intertechno-cc1101",
    use_scm_version=True,
    packages=setuptools.find_packages(),
    description="Python Library & Command Line Tool to Switch Intertechno Outlets"
    " via CC1101 Transceiver",
    long_description=pathlib.Path(__file__).parent.joinpath("README.md").read_text(),
    long_description_content_type="text/markdown",
    author="Fabian Peter Hammerle",
    author_email="fabian@hammerle.me",
    url=_REPO_URL,
    project_urls={"Changelog": _REPO_URL + "/blob/master/CHANGELOG.md"},
    keywords=[
        "automation",
        "intertechno",
        "outlet",
        "power",
        "radio-frequency",
        "raspberry-pi",
        "remote-control",
    ],
    classifiers=[
        # https://pypi.org/classifiers/
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "Intended Audience :: End Users/Desktop",
        "Intended Audience :: System Administrators",
        "Operating System :: POSIX :: Linux",
        "Topic :: Home Automation",
    ],
    entry_points={
        "console_scripts": ["intertechno-cc1101 = intertechno_cc1101._cli:_main"]
    },
    install_requires=[
        # >=2.7.0 for CC1101.set_output_power()
        "cc1101>=2.7.0"
    ],
    setup_requires=["setuptools_scm"],
    tests_require=["pytest"],
)
